# ExotelPy
An unofficial python wrapper for the [Exotel API](https://developer.exotel.com/api)


## What is this for?
This is a python wrapper which provides you the ability to interact with the Exotel API. It also comes with certain utility methods which makes interacting with the Exotel API easier.
- Documentation : https://noorahealth.github.io/exotel-python/


## Installation
```
pip install exotelpy
```
